<?php

namespace OCA\SideMenu\AppInfo;

use OC;
use OC\Security\CSP\ContentSecurityPolicyNonceManager;
use OC\User\User;
use OCA\SideMenu\Service\AppRepository;
use OCP\AppFramework\App;
use OCP\IUserSession;
use OCP\Util;
use Psr\Container\ContainerInterface;

/**
 * class Application.
 *
 * @author Simon Vieille <simon@deblan.fr>
 */
class Application extends App
{
    /**
     * @var OC\AllConfig
     */
    protected $config;

    /**
     * @var ContentSecurityPolicyNonceManager
     */
    protected $cspnm;

    /**
     * @var User
     */
    protected $user;

    /**
     * {@inheritdoc}
     */
    public function __construct(array $urlParams = [])
    {
        parent::__construct('side_menu', $urlParams);

        $this->config = OC::$server->getConfig();
        $this->cspnm = OC::$server->getContentSecurityPolicyNonceManager();
        $this->user = OC::$server[IUserSession::class]->getUser();
    }

    /**
     * Checks if this app is enabled.
     */
    public function isEnabled(): bool
    {
        $enabled = true;

        if (null !== $this->user) {
            $enabled = (bool) $this->config->getUserValue($this->user->getUid(), 'side_menu', 'enabled', '1');
        }

        return $enabled;
    }

    /**
     * Registes services.
     */
    public function registerServices()
    {
        $container = $this->getContainer();

        $container->registerService('AppRepository', function (ContainerInterface $c) {
            return new AppRepository(new OC_App());
        });
    }

    /**
     * Registers assets.
     */
    public function registerAssets()
    {
        Util::addScript('side_menu', 'sideMenu');
        Util::addStyle('side_menu', 'sideMenu');

        $stylesheet = OC::$server->getURLGenerator()->linkToRoute(
            'side_menu.Css.stylesheet',
            [
                'v' => $this->config->getAppValue('side_menu', 'cache', '0'),
            ]
        );

        $script = OC::$server->getURLGenerator()->linkToRoute(
            'side_menu.Js.script',
            [
                'v' => $this->config->getAppValue('side_menu', 'cache', '0'),
            ]
        );

        Util::addHeader(
            'link',
            [
                'href' => $stylesheet,
                'rel' => 'stylesheet',
            ],
            ''
        );

        Util::addHeader(
            'script',
            [
                'src' => $script,
                'nonce' => $this->cspnm->getNonce(),
            ],
            ''
        );
    }
}
