<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Controller;

use OC;
use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\Response;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\IConfig;
use OCP\IRequest;
use OCP\IUserSession;

class JsController extends Controller
{
    /**
     * @var \OCP\IConfig
     */
    protected $config;

    /**
     * @param string $appName
     */
    public function __construct($appName, IRequest $request, IConfig $config)
    {
        parent::__construct($appName, $request);

        $this->config = $config;
    }

    /**
     * @NoAdminRequired
     * @NoCSRFRequired
     * @PublicPage
     *
     * @return Response
     */
    public function script()
    {
        $user = OC::$server[IUserSession::class]->getUser();
        $topMenuApps = (array) json_decode($this->config->getAppValue('side_menu', 'top-menu-apps', '[]'), true);
        $targetBlankApps = (array) json_decode($this->config->getAppValue('side_menu', 'target-blank-apps', '[]'), true);

        if ($user) {
            $userTopMenuApps = (array) json_decode($this->config->getUserValue($user->getUid(), 'side_menu', 'top-menu-apps', '[]'), true);

            if (!empty($userTopMenuApps)) {
                $topMenuApps = $userTopMenuApps;
            }

            $userTargetBlankMode = (int) $this->config->getUserValue($user->getUid(), 'side_menu', 'target-blank-mode', '1');
            $userTargetBlankApps = (array) json_decode($this->config->getUserValue($user->getUid(), 'side_menu', 'target-blank-apps', '[]'), true);

            if ($userTargetBlankMode === 2) {
                $targetBlankApps = $userTargetBlankApps;
            }
        }


        $parameters = [
            'opener-position' => $this->config->getAppValue('side_menu', 'opener-position', 'before'),
            'opener-hover' => (bool) $this->config->getAppValue('side_menu', 'opener-hover', '0'),
            'external-sites-in-top-menu' => (bool) $this->config->getAppValue('side_menu', 'external-sites-in-top-menu', 0),
            'force-light-icon' => (bool) $this->config->getAppValue('side_menu', 'force-light-icon', '0'),
            'hide-when-no-apps' => (bool) $this->config->getAppValue('side_menu', 'hide-when-no-apps', '0'),
            'loader-enabled' => (bool) $this->config->getAppValue('side_menu', 'loader-enabled', '1'),
            'always-displayed' => (bool) $this->config->getAppValue('side_menu', 'always-displayed', '0'),
            'big-menu' => (bool) $this->config->getAppValue('side_menu', 'big-menu', '0'),
            'top-menu-apps' => $topMenuApps,
            'target-blank-apps' => $targetBlankApps,
        ];

        $response = new TemplateResponse('side_menu', 'js/script', $parameters, 'blank');
        $response->addHeader('Content-Type', 'text/javascript');

        return $response;
    }
}
